==> appstream-glib-0.5.7.tar.xz: appstream-glib-0.5.7/libappstream-glib/appstream-glib.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __APPSTREAM_GLIB_H
#define __APPSTREAM_GLIB_H

#define __APPSTREAM_GLIB_H_INSIDE__

#include <as-app.h>
#include <as-app-gettext.h>
#include <as-bundle.h>
#include <as-checksum.h>
#include <as-enums.h>
#include <as-icon.h>
#include <as-image.h>
#include <as-inf.h>
#include <as-node.h>
#include <as-problem.h>
#include <as-profile.h>
#include <as-provide.h>
#include <as-release.h>
#include <as-screenshot.h>
#include <as-store.h>
#include <as-tag.h>
#include <as-version.h>
#include <as-utils.h>

#undef __APPSTREAM_GLIB_H_INSIDE__

#endif /* __APPSTREAM_GLIB_H */

==> appstream-glib-0.5.11.tar.xz: appstream-glib-0.5.11/libappstream-glib/appstream-glib.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __APPSTREAM_GLIB_H
#define __APPSTREAM_GLIB_H

#define __APPSTREAM_GLIB_H_INSIDE__

#include <as-app.h>
#include <as-app-builder.h>
#include <as-bundle.h>
#include <as-checksum.h>
#include <as-enums.h>
#include <as-icon.h>
#include <as-image.h>
#include <as-inf.h>
#include <as-markup.h>
#include <as-node.h>
#include <as-problem.h>
#include <as-profile.h>
#include <as-provide.h>
#include <as-release.h>
#include <as-screenshot.h>
#include <as-store.h>
#include <as-tag.h>
#include <as-translation.h>
#include <as-version.h>
#include <as-utils.h>

#undef __APPSTREAM_GLIB_H_INSIDE__

#endif /* __APPSTREAM_GLIB_H */
